{% if field.help_text %}
    {% if help_text_inline %}
        <p id="hint_{{ field.auto_id }}" class="text-gray-600">{{ field.help_text|safe }}</p>x
    {% else %}
        <small id="hint_{{ field.auto_id }}" class="text-gray-600">{{ field.help_text|safe }}</small>
    {% endif %}
{% endif %}
