{% if formset.non_form_errors %}
    <div class="alert alert-error mb-4">
        {% if formset_error_title %}
            <div class="font-bold rounded-t">
                {{ formset_error_title }}
            </div>
        {% endif %}
        <div>
            <ul>
                {{ formset.non_form_errors|unordered_list }}
            </ul>
        </div>
    </div>
{% endif %}
