{% load daisyui_field %}

<div{% if div.css_id %} id="{{ div.css_id }}"{% endif %} class="{% if wrapper_class %} {{ wrapper_class }}{% endif %}{% if field.css_classes %} {{ field.css_classes }}{% endif %}{% if div.css_class %} {{ div.css_class }}{% endif %}" {{ div.flat_attrs|safe }}>
    {% if field.label and form_show_labels %}
        <label for="{{ field.id_for_label }}" class="{{ label_class }}{% if field.field.required %} requiredField{% endif %}">
            {{ field.label|safe }}{% if field.field.required %}<span class="asteriskField">*</span>{% endif %}
        </label>
    {% endif %}

    <div class="join w-full{% if field_class %} {{ field_class }}{% endif %}">
        {% daisyui_field field "class" "input join-item w-full" %}
        <span class="join-item flex items-center bg-base-200">{{ buttons|safe }}</span>
    </div>
    {% include 'daisyui/layout/help_text_and_errors.html' %}
</div>
